Сменить язык

[![en](https://img.shields.io/badge/lang-en-red.svg)](https://github.com/04Maksimka/AstraGeek/blob/main/README.md)
[![ru](https://img.shields.io/badge/lang-ru-green.svg)](https://github.com/04Maksimka/AstraGeek/blob/main/README.ru.md)

# 🌌 AstraGeek. Звездный атлас

Проект онлайн-школы астрономии AstraGeek.
Здесь вы можете найти программное обеспечение для создания звездных карт.

На [сайте](https://skychart.astrageek.ru/) проекта AstraGeek вы можете создавать классические небесные диаграммы и карты звездного неба.

Также посетите сайт [astrageek.ru](https://astrageek.ru/), где вы найдете обучающие видео по астрономии и на смежные темы.

---

## План выпуска

1. Стереографическая проекция звездного неба (скайчарт) в соответствии с 
   заданным географическим положением и временем. Также доступно отображение планет, больших кругов (эклиптики, небесного и галактического экватора). Доступно отображение горизонтальной и экваториальной сетки координат, сторон света. В качестве примера, в процессе разработки мы ориентировались на скайчарты с [этого сайта](https://skyatlas.app/star-charts/).

2. Построение отдельных участков неба в режиме камеры-обскуры. Этот режим 
   предоставляет все те же возможности, что и в 0.1, но в другой проекции неба. Можно отобразить созвездия по названию, задать поле зрения, угол поворота камеры и размер полученного изображения.

0.3 Анимация прохождения планет (gif и статические последовательности изображений)

0.4 Прецессия вращения Земли

---

## Особенности

1. Классическая стереографическая проекция всего неба, доступного к наблюдению в указанном месте и в указанное время.
2. Режим камеры-обскуры для определенной небольшой области неба в указанном направлении (выбранное созвездие)
3. Можно добавлять различные дополнительные опорные элементы: координатные сетки, большие координатные круги (эклиптика, галактический и небесный экватор), стороны света, точку зенита и небесные полюса.
4. Можно добавить к изображению контуры всех видимых созвездий или отдельных выбранных созвездий, а также названия каждого видимого или избранного созвездия.

---

## Примеры

Пример режима камеры-обскуры (без условных обозначений):

<img alt="изображение" src="https://github.com/user-attachments/assets/c73f3266-20ec-4617-b763-e1647df4d081" style="max-width: 100%; height: auto;" />

[Скачать файл](https://github.com/user-attachments/files/24474532/pinhole_local_logo.pdf)


Пример режима стереографической проекции (без условных обозначений):

<img alt="изображение" src="https://github.com/user-attachments/assets/dfd66621-1e12-43cb-b6c1-06ad275bdd12" style="max-width: 100%; height: auto;" />

[Скачать файл](https://github.com/user-attachments/files/24474544/polar_scatter_local_logo.pdf)

---

## Как использовать

**Если Вы хотите генерировать карты самостоятельно, то переходите сразу к 
разделу документации ниже**

Вы можете пользоваться готовыми наборами карт звездного неба, которые мы уже сгенерировали. Для этого:

1. Перейдите по [ссылке](https://drive.google.com/drive/folders/1AfBc7pkqLH_65TMAeXvpzzzqrLcVKNFO?usp=sharing)
2. Скачайте архивы pinhole_samples.zip и samples.zip с картами режима камеры-обскуры и скайчартами соответственно

Внутри каждой папки находятся сгруппированные по номерам карты звездного неба с заданиями. 

Внутри папки pinhole_samples находятся две папки:

1. **constellations**  - карты с конкретным центральным созвездием, для каждого из 88 созвездий
2. **random_sky** - карты с произвольным центральным созвездием, 10 примеров

Внутри папки samples сгруппированы скайчарты на произвольные дату и место

Каждая группа состоит из трех файлов карт:

1. Для ученика без планет, пустой классический скайчарт - _student.pdf_
2. Для ученика с планетами - _student_with_planets.pdf_
3. Для учителя - _teacher.pdf_

Каждый файл состоит из двух страниц: на первой находятся задания к карте, на второй непосредственно сама карта.

Файл для ученика содержит только задания и "голую" карту. Файл для учителя содержит все ответы и заполненную карту

---

## Документация

| Раздел | Ссылка                                                           |
| ---------------- |------------------------------------------------------------------|
| Узнать больше | [Документация](https://04maksimka.github.io/AstraGeek/)          |
| Проект на GitHub| [Репозиторий на GitHub](https://github.com/04Maksimka/AstraGeek) |
| Обратная связь | [Issue](https://github.com/04Maksimka/AstraGeek/issues/new)      |

---






